@@ -32,5 +32,6 @@ $INIT_BREAK
 """
 
     def __init__(self, *args, **kwargs):
+        if "port" not in kwargs:
+            kwargs["port"] = ":2000"
         super().__init__(*args, **kwargs)
-        self.port = ":2000"
