@@ -28,7 +28,7 @@ from platformio.util import memoized
 
 
 class BaseSchema(Schema):
-    class Meta(object):  # pylint: disable=no-init
+    class Meta:
         unknown = marshmallow.EXCLUDE  # pylint: disable=no-member
 
     def load_manifest(self, data):
@@ -232,7 +232,7 @@ class ManifestSchema(BaseSchema):
     )
 
     @validates("version")
-    def validate_version(self, value):  # pylint: disable=no-self-use
+    def validate_version(self, value):
         try:
             value = str(value)
             assert "." in value
@@ -243,17 +243,19 @@ class ManifestSchema(BaseSchema):
                 if "Invalid leading zero" in str(exc):
                     raise exc
             semantic_version.Version.coerce(value)
-        except (AssertionError, ValueError):
+        except (AssertionError, ValueError) as exc:
             raise ValidationError(
                 "Invalid semantic versioning format, see https://semver.org/"
-            )
+            ) from exc
 
     @validates("license")
     def validate_license(self, value):
         try:
             spdx = self.load_spdx_licenses()
-        except requests.exceptions.RequestException:
-            raise ValidationError("Could not load SPDX licenses for validation")
+        except requests.exceptions.RequestException as exc:
+            raise ValidationError(
+                "Could not load SPDX licenses for validation"
+            ) from exc
         known_ids = set(item.get("licenseId") for item in spdx.get("licenses", []))
         if value in known_ids:
             return True
